@@ -7,19 +7,20 @@ package Comics::Plugin::JHall;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.01";
+our $VERSION = "1.03";
 
 our $name    = "JHall";
 our $url     = "https://jhallcomics.com/";
 
 our $pattern =
-  qr{ <div \s+ .*? class="image-block-wrapper \s+ .*? > \s*
-      <noscript>
-      <img \s+
-       src="(?<url>https?://static1.squarespace.com/static/
-                   .*?/t/.*?/.*?/
-		   (?<image>.+?\.\w+))"
-    }sx;
+	    qr{ <noscript>
+		<img \s+ src="(?<url>https?://images.squarespace-cdn.com/
+		content/v1/
+		[-_0-9a-z]+/
+		[-_0-9a-z]+/
+		[-_0-9a-z]+/
+		(?<image>[^./]+\.\w+))"
+	       }xi,
 
 # Important: Return the package name!
 __PACKAGE__;
